@@ -1,7 +1,7 @@
 import praw
 import os
 import sys
-from . import botfiles
+from . import botfiles, correctMessage, incorrectMessage
 from sty import fg
 
 if sys.platform == 'win32':
@@ -14,7 +14,7 @@ cwd = os.getcwd()
 try:
     os.chdir(botfiles.botconfig)
     reddit = praw.Reddit('botterino')
-    print(f'{fg.green}Sucessfully logged into reddit as {reddit.user.me()}')
+    print(f'{fg.green}Successfully logged into reddit as {reddit.user.me()}')
 except Exception as e:
     print(f'{fg.red}Unable to login to reddit. Please check {botfiles.prawconfig}')
     print(f'{fg.red}{e}')
@@ -32,4 +32,3 @@ donotreply = {
     'imreallycuriousbird',
 }
 
-incorrect = '❌'
