@@ -1,11 +1,11 @@
 from geopy.distance import distance
 from geopy.point import Point
-from .config import donotreply, incorrect, reddit, username, pg
+from .config import donotreply, correctMessage, incorrectMessage, reddit, username, pg
 from itertools import permutations
 import re
 from sty import fg
-from .Utils.utils import decimal, getComments, getDistance, randomColor, randomColorWithAuthor
-
+from .Utils.utils import decimal, getComments, getDistance, randomColor, randomColorWithAuthor, MAPS_URL
+from difflib import SequenceMatcher
 
 def withinTolerance(guess, answer, tolerance):
     return distance(guess, answer).m <= tolerance
@@ -35,19 +35,38 @@ def checkMultipleCoordinates(guess, answers, tolerances):
 def checkCoordinates(guess, answer, tolerance):
     guesser = guess.author.name
     answer = Point(answer)
-    error = getDistance(guess.body, answer)
+    errorAndPoint = getDistance(guess.body, answer)
+    error, point = errorAndPoint if errorAndPoint else (None, None)
     if error is None:
         print(f"{randomColorWithAuthor(guesser)}Could not find a coordinate in guess '{guess.body}' by {guesser}")
         return 'ignore'
     error = round(error, 2)
-    print(f'{randomColorWithAuthor(guesser)}{guesser}\'s guess {guess.body} was {error} meters off')
+    mapslink = MAPS_URL.format(point.latitude, point.longitude)
+    print(f'{randomColorWithAuthor(guesser)}{guesser}\'s guess {mapslink} was {error} meters off')
     return error <= tolerance
 
+def checkText(guess, answer, tolerance, ignorecase):
+    guesser = guess.author.name
+    text = guess.body.strip().replace('\\', '')
+
+    if ignorecase:
+        text,answer = text.lower(), answer.lower()
+
+    similarity = SequenceMatcher(None, text, answer).ratio()
+    print(f'{randomColorWithAuthor(guesser)}{guesser}\'s guess was {round(similarity * 100, 3)}% similar to the correct answer')
+    return similarity >= tolerance
+
 def checkAnswers(r, submission):
-    tolerance, manual, after, text, answer, tolerances, answers = float(r.get('tolerance', 0)), r.get(
-        'manual'), r.get('after'), r.get('text'), r.get('answer'), r.get('tolerances'), r.get('answers')
-    if not tolerance and not tolerances:
+    tolerance, manual, after, text, answer, tolerances, answers, similarity, ignorecase = r.get(
+        'tolerance'), r.get('manual'), r.get('after'), r.get('text'), r.get(
+            'answer'), r.get('tolerances'), r.get('answers'), r.get(
+                'similarity'), r.get('ignorecase')
+
+    if tolerance is None and tolerances is None and text is None:
         return
+
+    tolerance = float(tolerance)
+
     for c in getComments(submission):
         result = True
         if tolerance:
@@ -61,13 +80,22 @@ def checkAnswers(r, submission):
                 print('{fg.red}Refusing to check answers, number of tolerances must equal number of answers.')
             result = result and checkMultipleCoordinates(c, answers, tolerances)
 
+        if text and similarity is None:
+            continue
+
+        if ignorecase is None:
+            ignorecase = True
+
+        if text:
+            result = result and checkText(c, text, similarity, ignorecase)
+
         if not result:
-            c.reply(incorrect)
+            c.reply(incorrectMessage)
         if result:
             if manual:
                 print(f"{randomColor()}Guess '{c.body}' looks correct, but you will have to check it out.")
             else:
-                plusCorrect = c.reply('+correct')
+                plusCorrect = c.reply(correctMessage)
                 guesser = c.author.name
                 print(
                     f'{randomColorWithAuthor(guesser)}Corrected {guesser} in {plusCorrect.created_utc - c.created_utc}s')
